@@ -7,7 +7,6 @@ use MyApp::Service::Chat;
 use MyApp::Service::Auth;
 
 use Beekeeper::Client;
-use Beekeeper::Config;
 
 my $Help = "Available commands:
   /login username pass   Login
@@ -23,16 +22,16 @@ sub new {
     my $self = {};
 
     $self->{fh} = $args{'fh'} || \*STDIN;
-    binmode STDOUT, ":utf8";
-    binmode STDIN,  ":utf8";
 
-    my $config = Beekeeper::Config->read_config_file('client.config.json');
+    # Choose a random frontend
+    my $frontend_configs = Beekeeper::Config->get_cluster_config( cluster => 'frontend' );
+    my $frontend = $frontend_configs->[rand @$frontend_configs];
+    my $bus_id = $frontend->{'bus-id'};
 
-    # Connect to bus 'frontend', wich will forward requests to 'backend'
-    $self->{client} = Beekeeper::Client->instance(
-        bus_role   => "frontend",
-        forward_to => "backend",
-        %$config,
+    # Connect to bus 'frontend-A', wich will forward requests to 'backend'
+    $self->{client} = Beekeeper::Client->instance( 
+        bus_id     => $bus_id,   # 'frontend-A' 
+        forward_to => 'backend',
     );
 
     $self->{chat} = MyApp::Service::Chat->new;
@@ -68,9 +67,7 @@ sub read_line {
 
     $self->{hdl}->push_read( line => sub {
         my ($hdl, $line) = @_;
-        print "\033[1A\033[K";  # move one line up and clear it
-        eval { $self->process_cmd($line) };
-        if ($@) { print "Error: $@" }
+        $self->process_cmd($line);
         $self->read_line;
     });
 }
