@@ -32,7 +32,7 @@ Version 0.01
   $stomp->subscribe(
       destination => '/topic/foo',
       on_receive_msg => sub {
-          my ($body, \$headers) = @_;
+          my ($body, $headers) = @_;
           print "Got message: $$body";
       },
   );
@@ -65,9 +65,9 @@ a randomly choosen node of the cluster.
 
 Port of the STOMP server. If not specified use the STOMP default of 61613.
 
-=item ssl
+=item tls
 
-Enable the use of SSL for STOMP connections.
+Enable the use of TLS for STOMP connections.
 
 =item vhost
 
@@ -216,8 +216,8 @@ sub _connect {
 
     # TCP connection args
     my $host = shift @$try_hosts;
-    my $ssl  = $config->{'ssl'}  || 0;
-    my $port = $config->{'port'} || ( $ssl ? 61612 : 61613 );
+    my $tls  = $config->{'tls'}  || 0;
+    my $port = $config->{'port'} || 61613;
 
     # STOMP connection args
     my %connect_hdr = (
@@ -239,7 +239,7 @@ sub _connect {
 
     $self->{handle} = AnyEvent::Handle->new(
         connect    => [ $host, $port ],
-        tls        => $ssl ? 'connect' : undef,
+        tls        => $tls ? 'connect' : undef,
         keepalive  => 1,
         no_delay   => 1,
         on_connect => sub { 
@@ -344,16 +344,17 @@ sub _connect {
                     # Extract server properties
                     $self->{version} = $frame_hdr{'version'};
                     $self->{server}  = $frame_hdr{'server'};
-                    $self->{is_rabbitmq} = 1 if ($self->{server} =~ m/RabbitMQ/i);
-                    $self->{is_activemq} = 1 if ($self->{server} =~ m/ActiveMQ/i);
-                    $self->{is_artemis}  = 1 if ($self->{server} =~ m/Artemis/i); # it is also ActiveMQ
+                    $self->{is_rabbitmq} = 1 if ($self->{server} =~ m|RabbitMQ/|i); # "RabbitMQ/3.8.3"
+                    $self->{is_activemq} = 1 if ($self->{server} =~ m|ActiveMQ/|i); # "ActiveMQ/5.15.12"
+                    $self->{is_artemis}  = 1 if ($self->{server} =~ m|Artemis/|i);  # "ActiveMQ-Artemis/2.12.0 ActiveMQ Artemis Messaging Engine"
                     # Call the user defined callback
                     my $cb = $self->{connect_cb};
                     $cb->(\%frame_hdr) if $cb;
                 }
                 elsif ($frame_cmd eq 'ERROR') {
                     # Server will close the connection after reporting any error
-                    my $errmsg = $frame_hdr{'message'} . ": " . $body;
+                    my $errmsg = $frame_hdr{'message'};
+                    $errmsg .= ": $body" if ($body && !$self->{is_activemq});
                     $self->_reset_connection;
                     my $cb = $self->{error_cb};
                     $cb ? $cb->($errmsg) : die "$errmsg\n";
@@ -509,9 +510,14 @@ sub subscribe {
     }
 
     if ($self->{is_activemq}) {
-        # Prefetch syntax is different in ActiveMQ
+        # Specific multi level wildcard
+        $headers{'destination'} =~ s/#/>/;
+        # Specific prefetch header
         my $prefetch = delete $headers{'prefetch-count'};
-        $headers{'prefetchSize'} = "$prefetch" if ($prefetch);
+        $headers{'activemq.prefetchSize'} = $prefetch if (defined $prefetch);
+        # Specific exclusive header
+        my $exclusive = delete $headers{'exclusive'};
+        $headers{'activemq.exclusive'} = 'true' if ($exclusive);
     }
 
     # Determine subscription id
@@ -544,7 +550,7 @@ sub subscribe {
         "\n\x00",
     );
 
-    #TODO: do not assume subscribe success
+    # Assume subscribe success (otherwise connection will be closed by broker)
     $self->{subscriptions}->{$destination} = $subscr_id;
 
     return $subscr_id;
@@ -676,6 +682,12 @@ sub send {
         $headers{'receipt'} = $receipt_id;
     }
 
+    if ($self->{is_activemq} && exists $headers{'expiration'}) {
+        # Specific expiration header for ActiveMQ
+        my $expiration = delete $headers{'expiration'};
+        $headers{'expires'} = $expiration ? int($expiration + AE::now * 1000) : 0;
+    }
+
     my $buffer_id = delete $headers{'buffer_id'};
 
     my $raw_stomp = join( "",
@@ -959,6 +971,8 @@ sub DESTROY {
 
 1;
 
+=encoding utf8
+
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
