@@ -3,7 +3,42 @@ package Beekeeper::Logger;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.01';
+
+=head1 NAME
+
+Beekeeper::Logger - Default logger used by worker processes.
+
+=head1 VERSION
+
+Version 0.01
+
+=head1 SYNOPSIS
+
+  use Beekeeper::Worker ':log';
+  use base 'Beekeeper::Worker';
+
+  log_debug 'Ready';
+
+=head1 DESCRIPTION
+
+By default all workers use a C<Beekeeper::Logger> logger which logs errors and
+warnings both to files and to a topic on the message bus. 
+
+Logs location can be specified with option C<log_file> in config file C<pool.config.json>.
+
+If no location is specified log files are are saved on C</var/log> when running pools
+as root, or C</var/log/{user}> when running as another user (if that directory
+already exists).
+
+Log entries are also sent to a topic C</topic/log> in the message bus. The command 
+line tool C<bkpr-log> allows to inspect this topic in real time. Having a common topic
+for logs allows to easily shovel them to an external log management system.
+
+To replace this default log mechanism for another one of your choice, just override 
+in your worker class the inherithed method C<log_handler>.
+
+=cut
 
 use constant LOG_FATAL  => 1;
 use constant LOG_ALERT  => 2;
@@ -145,13 +180,9 @@ sub log {
     local $@;
 
     eval {
-
-        my $service = $self->{service};
-        $service =~ tr|.|/|;
-
-        $bus->publish(
-            topic   => "log/$level/$service",
-            payload => \$json,
+        $bus->send(
+            'destination' => "/topic/log.$level.$self->{service}",
+            'body'        => \$json,
         );
     };
 
@@ -163,52 +194,15 @@ sub log {
 
 1;
 
-__END__
-
-=pod
-
 =encoding utf8
 
-=head1 NAME
-
-Beekeeper::Logger - Default logger used by worker processes.
-
-=head1 VERSION
-
-Version 0.03
-
-=head1 SYNOPSIS
-
-  use Beekeeper::Worker ':log';
-  use base 'Beekeeper::Worker';
-  
-  log_debug 'Ready';
-
-=head1 DESCRIPTION
-
-By default all workers use a C<Beekeeper::Logger> logger which logs errors and
-warnings both to files and to a topic on the message bus. 
-
-Logs location can be specified with option C<log_file> in config file C<pool.config.json>.
-
-If no location is specified log files are are saved on C</var/log> when running pools
-as root, or C</var/log/{user}> when running as another user (if that directory
-already exists).
-
-Log entries are also sent to a topic C</topic/log> in the message bus. The command 
-line tool C<bkpr-log> allows to inspect this topic in real time. Having a common topic
-for logs allows to easily shovel them to an external log management system.
-
-To replace this default log mechanism for another one of your choice, just override 
-in your worker class the inherithed method C<log_handler>.
-
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015-2021 José Micó.
+Copyright 2015 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
