@@ -3,7 +3,25 @@ package Beekeeper::Service::Supervisor::Worker;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.01';
+
+=head1 NAME
+
+Beekeeper::Service::Supervisor::Worker - Worker pool supervisor.
+
+=head1 VERSION
+
+Version 0.01
+
+=head1 DESCRIPTION
+
+A Supervisor worker is created automatically in every worker pool.
+
+It keeps a shared table of the status of every worker connected to a logical 
+bus in every broker, routinely checking local workers and keeping track of 
+workers periodic performance reports.
+
+=cut
 
 use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
@@ -15,18 +33,19 @@ use constant CHECK_PERIOD => Beekeeper::Worker::REPORT_STATUS_PERIOD;
 
 sub authorize_request {
     my ($self, $req) = @_;
+    my $required;
 
     if ($req->{method} eq '_bkpr.supervisor.worker_status' ||
         $req->{method} eq '_bkpr.supervisor.worker_exit' ) {
-
-        return unless $self->__has_authorization_token('BKPR_SYSTEM');
+        $required = 'BKPR_SYSTEM';
     }
     else {
-
-        return unless $self->__has_authorization_token('BKPR_ADMIN');
+        $required = 'BKPR_ADMIN';
     }
 
-    return BKPR_REQUEST_AUTHORIZED;
+    return unless $req->has_auth_tokens( $required );
+
+    return REQUEST_AUTHORIZED;
 }
 
 sub on_startup {
@@ -44,7 +63,7 @@ sub on_startup {
         '_bkpr.supervisor.restart_workers' => 'restart_workers',
     );
 
-    $self->accept_remote_calls(
+    $self->accept_jobs(
         '_bkpr.supervisor.worker_status'       => 'worker_status',
         '_bkpr.supervisor.worker_exit'         => 'worker_exit',
         '_bkpr.supervisor.get_workers_status'  => 'get_workers_status',
@@ -68,12 +87,33 @@ sub log_handler {
     $self->SUPER::log_handler( foreground => 1 );
 }
 
+=item worker_status
+
+Handler for 'supervisor.worker_status' job.
+
+This job is sent by workers every few seconds and acts as a heart-beat.
+It contains statistical data about worker performance.
+
+Note that workers doing long jobs (like slow SQL queries) may not send 
+this request timely.
+
+=cut
+
 sub worker_status {
     my ($self, $params) = @_;
 
     $self->set_worker_status( %$params );
 }
 
+=item on_worker_exit
+
+Handler for 'supervisor.worker_exit' job.
+
+This job is sent by workers just before exiting gracefully. It is not sent 
+when worker is terminated abruptly (as process has no chance to do so).
+
+=cut
+
 sub worker_exit {
     my ($self, $params) = @_;
 
@@ -83,6 +123,7 @@ sub worker_exit {
     $self->check_queues;
 }
 
+
 sub set_worker_status {
     my ($self, %args) = @_;
 
@@ -144,6 +185,19 @@ sub _get_workers {
 }
 
 
+=item check_workers
+
+Check every worker process in this host (even workers in other pools) to
+ensure that they are running, and measure their memory usage.
+
+This is needed as workers with long blocking procedures may not report its 
+status timely, and abruptly terminated workers has no chance to report that 
+they had exited.
+
+It would be nice to measure CPU usage too.
+
+=cut
+
 sub check_workers {
     my $self = shift;
 
@@ -213,6 +267,19 @@ sub check_workers {
     }
 }
 
+=item check_queues
+
+In the case of all workers of a given service being down, all requests sent to
+the service will timeout as no one is serving them. This may cause a serious
+disruption in the application, as any other service depending of the broken
+one will halt too for the duration of the timeout.
+
+In order to mitigate this situation the Sinkhole service will be notified
+when unserviced queues are detected, making it to respond immediately to 
+all requests with an error response. Then callers will quickly receive an
+error response instead of timing out.
+
+=cut
 
 sub check_queues {
     my $self = shift;
@@ -240,14 +307,20 @@ sub check_queues {
     # Tell Sinkhole to respond immediately to all requests sent to 
     # unserviced queues with a "Method not available" error response
 
-    my $guard = $self->__use_authorization_token('BKPR_SYSTEM');
-
     $self->send_notification(
         method => '_bkpr.sinkhole.unserviced_queues',
+        __auth => 'BKPR_SYSTEM',
         params => { queues => \@unserviced },
     );
 }
 
+=item get_workers_status
+
+Handler for 'supervisor.get_workers_status' job.
+
+Used by bkpr-top command line tool.
+
+=cut
 
 sub get_workers_status {
     my ($self, $args) = @_;
@@ -261,6 +334,13 @@ sub get_workers_status {
     return $workers;
 }
 
+=item get_services_status
+
+Handler for 'supervisor.get_services_status' job.
+
+Used by bkpr-top command line tool.
+
+=cut
 
 sub get_services_status {
     my ($self, $args) = @_;
@@ -275,7 +355,7 @@ sub get_services_status {
 
     foreach my $worker (@$workers) {
         $services{$worker->{class}}{count}++;
-        $services{$worker->{class}}{cps}  += $worker->{cps};
+        $services{$worker->{class}}{jps}  += $worker->{jps};
         $services{$worker->{class}}{nps}  += $worker->{nps};
         $services{$worker->{class}}{cpu}  += $worker->{cpu} || 0;
         $services{$worker->{class}}{mem}  += $worker->{mem} || 0;
@@ -287,7 +367,7 @@ sub get_services_status {
     }
 
     foreach my $service (values %services) {
-        $service->{cps}  = sprintf("%.2f", $service->{cps} );
+        $service->{jps}  = sprintf("%.2f", $service->{jps} );
         $service->{nps}  = sprintf("%.2f", $service->{nps} );
         $service->{cpu}  = sprintf("%.2f", $service->{cpu} );
         $service->{mem}  = sprintf("%.2f", $service->{mem} );
@@ -297,6 +377,13 @@ sub get_services_status {
     return \%services;
 }
 
+=item restart_workers
+
+Handler for 'supervisor.restart_workers' notification.
+
+This request is sent by bkpr-restart command line tool.
+
+=cut
 
 sub restart_workers {
     my ($self, $args) = @_;
@@ -345,6 +432,13 @@ sub restart_workers {
     }
 }
 
+=item restart_pool
+
+Handler for 'supervisor.restart_pool' notification.
+
+This request is sent by bkpr-restart command line tool.
+
+=cut
 
 sub restart_pool {
     my ($self, $args) = @_;
@@ -399,97 +493,15 @@ sub _get_pool_index {
 
 1;
 
-__END__
-
-=pod
-
 =encoding utf8
 
-=head1 NAME
-
-Beekeeper::Service::Supervisor::Worker - Worker pool supervisor.
-
-=head1 VERSION
-
-Version 0.06
-
-=head1 DESCRIPTION
-
-A Supervisor worker is created automatically in every worker pool.
-
-It keeps a shared table of the status of every worker connected to a logical 
-bus in every broker, routinely checking local workers and keeping track of 
-workers periodic performance reports.
-
-=head3 worker_status
-
-Handler for 'supervisor.worker_status' request.
-
-This request is made by workers every few seconds and acts as a heart-beat.
-It contains statistical data about worker performance.
-
-Note that workers processing long tasks (like slow SQL queries) may not make 
-this request timely.
-
-=head3 on_worker_exit
-
-Handler for 'supervisor.worker_exit' request.
-
-This request is made by workers just before exiting gracefully. It is not made 
-when a worker is terminated abruptly (as the process has no chance to do so).
-
-=head3 check_workers
-
-Check every worker process in this host (even workers in other pools) to
-ensure that they are running, and measure their memory and CPU usage.
-
-This is needed as workers with long blocking procedures may not report its 
-status timely, and abruptly terminated workers has no chance to report that 
-they had exited.
-
-=head3 check_queues
-
-In the case of all workers of a given service being down, all requests sent to
-the service will timeout as no one is serving them. This may cause a serious
-disruption in the application, as any other service depending of the broken
-one will halt too for the duration of the timeout.
-
-In order to mitigate this situation the Sinkhole service will be notified
-when unserviced queues are detected, making it to respond immediately to 
-all requests with an error response. Then callers will quickly receive an
-error response instead of timing out.
-
-=head3 get_workers_status
-
-Handler for 'supervisor.get_workers_status' request.
-
-Used by bkpr-top command line tool.
-
-=head3 get_services_status
-
-Handler for 'supervisor.get_services_status' request.
-
-Used by bkpr-top command line tool.
-
-=head3 restart_workers
-
-Handler for 'supervisor.restart_workers' notification.
-
-This request is sent by bkpr-restart command line tool.
-
-=head3 restart_pool
-
-Handler for 'supervisor.restart_pool' notification.
-
-This request is sent by bkpr-restart command line tool.
-
 =head1 AUTHOR
 
 José Micó, C<jose.mico@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015-2021 José Micó.
+Copyright 2015 José Micó.
 
 This is free software; you can redistribute it and/or modify it under the same 
 terms as the Perl 5 programming language itself.
