@@ -20,9 +20,9 @@ Simple worker used to test shared cache.
 sub on_startup {
     my $self = shift;
 
-    $self->{Cache} = $self->shared_cache( id => "test", max_age => 20 );
+    $self->{Cache} = $self->shared_cache( id => "test", max_age => 10 );
 
-    $self->accept_remote_calls(
+    $self->accept_jobs(
         'cache.set'  => 'set',
         'cache.get'  => 'get',
         'cache.del'  => 'del',
@@ -36,7 +36,7 @@ sub on_startup {
 sub authorize_request {
     my ($self, $req) = @_;
 
-    return BKPR_REQUEST_AUTHORIZED;
+    return REQUEST_AUTHORIZED;
 }
 
 sub get {
